@@ -169,12 +169,17 @@ void mdaEPiano::update()  //parameter change
 }
 
 
+void mdaEPiano::setSampleRate(float rate)
+{
+    AudioEffectX::setSampleRate(rate);
+    Fs = rate;
+    iFs = 1.0f / Fs;
+    dlfo = 6.283f * iFs * (float)exp(6.22f * programs[curProgram].param[5] - 2.61f); //lfo rate
+}
+
+
 void mdaEPiano::resume()
 {
-  Fs = getSampleRate();
-  iFs = 1.0f / Fs;
-  dlfo = 6.283f * iFs * (float)exp(6.22f * programs[curProgram].param[5] - 2.61f); //lfo rate
-
   DECLARE_LVZ_DEPRECATED (wantEvents) ();
 }
 
@@ -500,7 +505,7 @@ int32_t mdaEPiano::processEvent(const LV2_Atom_Event* ev)
   if (ev->body.type != midiEventType)
       return 0;
 
-  const uint8_t* midiData = (const uint8_t*)LV2_ATOM_BODY(&ev->body);
+  const uint8_t* midiData = (const uint8_t*)LV2_ATOM_BODY_CONST(&ev->body);
 
     switch(midiData[0] & 0xf0) //status byte (all channels)
     {
